@@ -34,3 +34,9 @@ class ExplainDetail(object):
     # The changelog mode produced by a physical rel node.
     # e.g. GroupAggregate(..., changelogMode=[I,UA,D])
     CHANGELOG_MODE = 1
+
+    # The execution plan in json format of the program.
+    JSON_EXECUTION_PLAN = 2
+
+    # The potential risk warnings and SQL optimizer tuning advice analyzed from the physical plan.
+    PLAN_ADVICE = 3
